
package bank.gui;


/*
 * Copyright (C) 1998 OGIS-RI. All Rights Reserverd.
 *
 */


import bank.manager.*;
import bank.util.*;
import bank.state.*;
import bank.boundary.*;

/**
 *ATM̉ʂ̃CxgۂɍsRg[NX
 *#pattern: Command
 *#pattern MVC
 *
 *@see bank.gui.Command
 *@see bank.client.AtmGui
 *@version 3.2 
 *@author Masashi Umezawa
 */
public class AtmGuiLogic implements Acceptable, Cancelable{
	
	protected BankApplicationManagerInterface appManager;
	protected AtmGuiState state;
	protected AtmGuiView view; 









/**
 * 
 */
public AtmGuiLogic () {
		this(new AtmGuiView(), new AtmGuiState());
}
/**
 * 
 * @param view bank.gui.ATMGuiView
 * @param state bank.state.ATMGuiState
 */
public AtmGuiLogic ( AtmGuiView view, AtmGuiState state) {
	this.setAtmGuiView(view);
	this.setAtmGuiState(state);
	state.addObserver(view);
}
/**
 * 
 */
public void accept() {
	state.accept();
}
/**
 * 
 */
public void cancel ( ) {
	state.cancel();
}
/**
 * 
 * @return int
 */
public int checkBalance(){
	int balance = 0;
	try{
		balance = appManager.checkBalanceAccount(state.getAccountNumber());
		state.setBalance(balance);
	} catch (AccountNotFoundException e){
		state.beCheckBalanceFailure();
	}		
	return balance;
}
/**
 * 
 * @param money int
 */
public int deposit(int money) throws MinusAmountException{
	int balance = 0;
	if (money < 0) { throw new MinusAmountException();}
	try{
		balance = appManager.depositAccount(state.getAccountNumber(), money);		
		state.setBalance(balance);
	} catch (AccountNotFoundException e){
		state.beDepositFailure();
	}		
	return balance;
}
/**
 * 
 * @return bank.state.AtmGuiState
 */
public AtmGuiState getAtmGuiState() {
	return state;
}
/**
 * 
 * @return bank.state.AtmGuiView
 */
public AtmGuiView getAtmGuiView() {
	return view;
}
/**
 *BankApplicationManager̃CX^X𕶎񂩂瓾ăCXg[
 *#pattern: strategy
 */
public void initManager(String managerClassName) {
	appManager = (BankApplicationManagerInterface)SingletonFactory.defaultInstance(managerClassName);	
}
/**
 * AtmGuiCommandĂ΂R[obN
 */
public void onCheckBalance(){
	this.checkBalance();
	state.beShowingAccount();
}
/**
 * AtmGuiCommandĂ΂R[obN
 */
public void onDeposit() {
	state.beAccountDepositing();
}
/**
 * AtmGuiCommandĂ΂R[obN
 */
public void onWithdraw() {
	state.beAccountWithdrawing();
}
/**
 * 
 * @param anAtmguiState AtmGuiState
 */
public void setAtmGuiState(AtmGuiState state) {
	this.state = state;
	state.setAtmGuiLogic(this);
}
/**
 * 
 * @param view bank.gui.AtmGuiView
 */
public void setAtmGuiView(AtmGuiView view) {
	this.view = view;
	view.setAtmGuiLogic(this);
}
/**
 * 
 * @param appMan bank.boundary.BankApplicationManagerInterface
 */
public void setBankApplicationManager(BankApplicationManagerInterface appManaber) {
	this.appManager = appManager;
}
/**
 * 
 * @param anAccountNumber int
 */
public boolean verifyAccount(int anAccountNumber){
		boolean verified; 
		if (anAccountNumber < 0) { verified = false;}
		verified = appManager.verifyAccount(anAccountNumber);
		return verified;	
}
/**
 * 
 * @return int
 * @param money int
 */
public int withdraw(int money) throws MinusAmountException, OverWithdrawException{
	int balance = 0;
	if (money < 0) { throw new MinusAmountException();}
	if (money > state.getBalance()) { throw new OverWithdrawException();}
	try {
		balance = appManager.withdrawAccount(state.getAccountNumber(), money);
		state.setBalance(balance);
	} catch (AccountNotFoundException e){
		state.beWithdrawFailure();
	}		
	return balance;
}
}