
package bank.gui;


/*
 * Copyright (C) 1998 OGIS-RI. All Rights Reserverd.
 *
 */

import java.awt.*;
import java.util.*;

import bank.util.*;

/**
 *AwtR|[lg쐬ACAEgsBuilderNX
 *#pattern: Builder
 *
 *@version 3.2 
 *@author Masashi Umezawa
 */
 
public class UiBuilder {
   protected Container target;
   protected Vector components;










UiBuilder() {
	components = new Vector();
}
/**
 * 
 * @param cont java.awt.Container
 */
public UiBuilder ( Container cont) {
	this();
	this.setTarget(cont);
}
public Container buildOn( Container cont) {
	Enumeration enu = components.elements();
	while(enu.hasMoreElements()){
	    Component comp = (Component)enu.nextElement();
	    cont.add(comp);
	}
	clearComponents();
	return cont;
}
public Panel buildWith( LayoutManager layoutManager) {
	Panel panel = new Panel();
	panel.setLayout(layoutManager);
	this.buildOn(panel);
	return panel;
}
public void clearComponents() {
	components.removeAllElements();
}
public Button makeButton(String aLabel) {
	Button button = new Button(aLabel);
	storeComponents(button);
	return button;
}
/**
 * 
 * @return java.awt.Button
 * @param callback Cancelable
 */
public Button makeCancelButton(Cancelable callback) {
	return this.makeCancelButton("Cancel", callback);
}
/**
 * 
 * @return java.awt.Button
 * @param  label java.lang.string
 * @param callback Cancelable
 */
public Button makeCancelButton(String label, Cancelable callback) {
	Button button =  this.makeButton(label);
	this.tieCancelButtonCommand(button, callback);
	return button;
}
public Label makeLabel(String aLabel) {
	Label label = new Label();
	label.setText(aLabel);
	storeComponents(label);
	return label;
}
public Button makeOKButton(Acceptable callback){
	return this.makeOKButton("OK", callback);
}
/**
 * 
 * @return 
 * @param callback bank.util.Acceptable
 * @param label java.lang.String
 */
public Button makeOKButton(String label, Acceptable callback) {
	Button button = this.makeButton(label);
	this.tieAcceptButtonCommand(button, callback);
	return button;
}
public Panel makePanel(LayoutManager aLayout) {
	Panel panel = new Panel();
	panel.setLayout(aLayout);
	storeComponents(panel);
	return panel;
}
public TextField makeTextField(int length) {
	TextField text = new TextField(length);
	storeComponents(text);
	return text;
}
protected GridBagConstraints setGridBagConstraints(int x, int y, int w, int h,GridBagConstraints gc) {
	gc.insets = new Insets(10,10,10,10);
	gc.weightx=1.0;
	gc.weighty=1.0;
	gc.gridx = x;
	gc.gridy = y;
	gc.gridwidth = w;
	gc.gridheight =h;
	return gc;
}
public Component setGridBagLayout(int x, int y, int w, int h,Component aComp,GridBagLayout gb,int fill) {
	GridBagConstraints gc = new GridBagConstraints();
	gc.fill = fill;
	gb.setConstraints(aComp,setGridBagConstraints(x,y,w,h,gc));
	return aComp;
}
public void setTarget(Container cont){
	this.target = cont;
}
protected void storeComponents(Component comp) {
	components.addElement(comp);
}
protected void tieAcceptButtonCommand(Button button, Acceptable callback){
		AcceptCommand command = new AcceptCommand(callback);
		button.addActionListener(command);
}
protected void tieButtonCommand(Button button, Command command){
		button.addActionListener(command);
}
protected void tieCancelButtonCommand(Button button, Cancelable callback){
		CancelCommand command = new CancelCommand(callback);
		button.addActionListener(command);
}
}