
package bank.manager;


/*
 * Copyright (C) 1998 OGIS-RI. All Rights Reserverd.
 *
 */

import bank.model.*;
import bank.storage.*;
import bank.util.*;
import bank.transaction.*;
import bank.boundary.*;

/**
 *sAvP[VɊւ鑀܂Ƃ߂Ď}l[WNX
 *#pattern: Facade
 *
 *@see bank.manager.AccountFinder
 *@version 3.2 
 *@author Masashi Umezawa
 */ 
public class BankApplicationManager extends DomainManager implements BankApplicationManagerInterface{
	protected AccountFinder accFinder;










public BankApplicationManager() {
	super();
	accFinder = new AccountFinder();
	accFinder.setDbAdaptorCreatePolicy(this.createPolicy());
}
/**
 * 
 * @return int
 * @param accountNumber int
 */
synchronized public int checkBalanceAccount(int accountNumber) throws AccountNotFoundException{
	int balance = 0;
	Account account = this.searchAccount(accountNumber);
	if (isLogOn){
	    logger.appendPreLog(new CheckBalanceTransaction(account));
	    balance = account.checkBalance();
	    logger.appendPostLog(new CheckBalanceTransaction(account));
	} else {
	    balance = account.checkBalance();
	}
	return balance;
}
protected DbAdaptorCreatePolicy createPolicy(){
	return new AccountDbAdaptorCreatePolicy();
}
/**
 * 
 * @return int
 * @param accountNo int
 * @param amount int
 */
synchronized  public int depositAccount(int accountNumber, int amount) throws AccountNotFoundException {
	int balance = 0;
	Account account = this.searchAccount(accountNumber);
	if (isLogOn){
			 logger.appendPreLog(new DepositTransaction(account));
			 balance = account.deposit(amount);
			 logger.appendPostLog(new DepositTransaction(account));
	} else {
	    balance = account.deposit(amount);
	}
	return balance;
}
/**
 * BankApplicationManager̓VOgƂĎ
 *#pattern: Singleton
 */
public static BankApplicationManager getDefault() {
	return (BankApplicationManager)(SingletonFactory.defaultInstance("bank.manager.BankApplicationManager"));;
}
/**
 * 
 * @return Account
 * @param accountNum int
 */
protected Account searchAccount (int accountNum ) throws AccountNotFoundException{
		return accFinder.find(accountNum);	
}
/**
 * 
 * @return Account
 * @param accountNum int
 */
synchronized  public boolean verifyAccount (int accountNum ){
	try{
		accFinder.find(accountNum);
	} catch (AccountNotFoundException e){
		return false;
	}
	return true;		
}
/**
 * 
 * @return int
 * @param accountNumber int
 * @param amount int
 */
synchronized  public int withdrawAccount(int accountNumber, int amount) throws AccountNotFoundException {
	int balance = 0;
	Account account = this.searchAccount(accountNumber);
	if (isLogOn){
	    logger.appendPreLog(new WithdrawTransaction(account));
	    balance = account.withdraw(amount);
	    logger.appendPostLog(new WithdrawTransaction(account));
	} else {
	    balance = account.withdraw(amount);
	}
	return balance;
}
}